/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area;

import nl.cloudfarming.eventbus.BaseGuiEventProducer;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventProducer;

/**
 * eventbus eventkey for area events
 *
 * @author Timon Veenstra
 */
public enum AreaEvent implements GuiEventKey {

    /**
     * new Fields have been imported
     */
    IMPORT_SAVED,
    /**
     * Data of a field have been updated, event should contain updated field
     */
    FIELD_UPDATE,
    /**
     *Data of a partfield have been updated, event should contain updated partfield
     */
    PARTFIELD_UPDATE,
    
    /**
     * Field has been removed
     */
    FIELD_REMOVED, 
    
    /**
     * Line removed
     */
    HELP_LINE_REMOVED;

    @Override
    public String getKey() {
        return this.toString();
    }
    
    /**
     * Static method to get a producer for this kind of events.
     * 
     * @return 
     */
    public static GuiEventProducer getProducer(){
        return new AreaEventProducer();
    }

    /**
     * The producer for this kind of events
     */
    public static class AreaEventProducer extends BaseGuiEventProducer {

        public AreaEventProducer() {
            super(AreaEvent.class);
        }
    }      
}
