/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area;

import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.MultiLineString;
import com.vividsolutions.jts.geom.MultiPolygon;
import java.util.Collection;
import nl.cloudfarming.client.model.BeanService;
import nl.cloudfarming.client.model.Field;
import nl.cloudfarming.client.model.HelpLine;

/**
 * interface which described functionality to access fields and related data
 *
 *
 * @author Timon Veenstra
 */
public interface AreaService extends BeanService {

    Collection<Field> findAllCurrentFields();
    
    /**
     * Create a new field with filled model object
     * 
     * @param field The field to create
     */
    Field createNewField(String name, MultiPolygon geometry, String code);

    /**
     * Remove a field
     * 
     * @param field 
     */
    public void removeField(Field field);

    /**
     * Sets the endDate of the field to now.
     * 
     * @param field the field that should be ended
     * @retrun boolean true if succesfull false if not succesfull
     * @throws IllegalArgumentException if the Provided field is not a persisted entity
     */
    public boolean endField(Field field);

    /**
     * Find all the fields where the endDate is not filled
     * @return all the active Fields
     */
    public Collection<HelpLine> findAllHelpLines();

    /**
     * Removes a line. If a field has partFields the field will not be removed. 
     * Instead the endDate of the field and all of its partFields will be filed.
     * 
     * @param field which will be removed
     */
    public void removeHelpLine(HelpLine line);

    public void createNewHelpLine(String name, MultiLineString geometry, String NAME);
}
